==> amazcart_v4.0.zip: amazcart_v4.0/resources/lang/default/seller.php <==
<?php
return [
    'create_a_seller' => 'Create a Seller',
    'subscription_type' => 'Subscription Type',
    'basic_info' => 'Basic Information',
    'shop_name' => 'Shop Name',
    'make_trusted' => 'Make Trusted',
    'remove_from_trusted' => 'Remove From Trusted',
    'alert_message' => 'Alert Message',
    'are_you_confirmed_to_execute_this_operation' => 'Are you confirmed to execute this operation ?',
    'yes' => 'yes',
    'business_information' => 'Business Information',
    'business_owner_name' => 'Legal Name/ Business Owner Name',
    'country_region' => 'Country/ Region',
    'person_in_charge_name' => 'Person in Charge Name',
    'business_registration_number' => 'Business Registration Number',
    'seller_tin' => 'Seller TIN',
    'upload_business_document' => 'Upload Business Document',
    'display_name' => 'Display Name',
    'shop_name' => 'Shop Name',
    'holiday_mode' => 'HoliDay Mode',
    'holiday_start' => 'Holiday Start',
    'holiday_end' => 'Holiday End',
    'upload_cheque_copy' => 'Upload Cheque Copy',
    'same_as_warehouse_address' => 'Same as Warehouse Address',
    'order_status' => 'Order Status',
    'delivery_status' => 'Delivery Status',
    'no_of_product' => 'No. of product',
    'txn_id' => 'TXN ID',
    'commission_type' => 'Commission Type',
    'approval' => 'Approval',
    'check_category_commissions' => 'Check Category Commissions',
    'category_list_with_commission' => 'Category list with Commission',
    'my_staff' => 'My Staff',
    'add_new_staff' => 'Add New Staff',
    'create_a_staff' => 'Create A Staff',
    'update_staff_info' => 'Update staff info',
    'joined_date' => 'Joined Date',
    'select_from_list' => 'Select from list',
    'add_member_is_disabled_according_to_your_package_right_now' => 'Add Member is disabled according to your package right now',
    'seller_list' => 'Seller List',
    'commision_setup' => 'Commision Setup',
    'subscription_payment' => 'Subscription Payment',
    'manage_seller' => 'Manage Seller',
    'subscription_info' => 'Subscription info',
    'subscription_title' => 'Subscription Title',
    'next_payment_before' => 'Next payment before',
    'subscription_payments' => 'Subscription payments',
    'create_supplier' => 'Create supplier',
    'business_name' => 'Business name',
    'tax_number' => 'Tax number',
    'edit_supplier' => 'Edit Supplier',
    'supplier_id' => 'Supplier id',
    'supplier' => 'Supplier',
    'supplier_list' => 'Supplier list',
    'pay_condition' => 'Pay condition',
    'finance_information' => 'Finance Information',
    'opening_balance' => 'Opening Balance',
    'pay_term' => 'PAY Term',
    'pay_term_condition' => 'Pay Term Condition',
    'alternate_contact_no' => 'Alternate Contact No',
    'postcode' => 'Postcode',
    'supplier_profile' => 'Supplier Profile',
    'office_xtract' => 'OfficeXtract',
    'please_update_business_bank_information_from_profile_first' => 'Please Update Business & Bank Information From Profile First.',
    'seller_profile' => 'Seller Profile',
    'product_allready_added' => 'Product Allready Added.',
    'about_seller' => 'About Seller',
    'commission_calculate_for_multi_category' => 'Commission Calculate For Multi Category',
    'minimum_rate' => 'Minimum Rate',
    'maximum_rate' => 'Maximum Rate',
    'average_rate' => "Average Rate",
    'multi_category' => 'Multi Category',
    'expire_date' => 'Expire date',
    'already_expired' => 'Already Expired',
    'last_payment_date' => 'Last Payment Date',
    'advance_renew_subscription' => 'Advance renew subscription',
    'after_change_and_save_previous_lisence_will_expried' => 'After change and save previous lisence will expried.',
    'Request/Inactive seller list' => 'Request/Inactive seller list',
    'Seller setting' => 'Seller setting',
    'Seller Order Manage' => 'Seller Order Manage',
    'order_refund_status' => 'Request Status',
    'is_refunded' => 'Is Refunded',
    'OrderRefund_action' =>'Action',
    'regular_seller' =>'Regular Seller',
    'total_commision' => 'Total Commision',
    'request_inactive_seller_list' => 'Request/Inactive Seller List',
    'seller_setting' => 'Seller Setting',
    'new_password' => "New Password"
];

==> amazcart_v4.4.zip: amazcart_v4.4/resources/lang/default/seller.php <==
<?php
return [
    'create_a_seller' => 'Create a Seller',
    'subscription_type' => 'Subscription Type',
    'basic_info' => 'Basic Information',
    'shop_name' => 'Shop Name',
    'make_trusted' => 'Make Trusted',
    'remove_from_trusted' => 'Remove From Trusted',
    'alert_message' => 'Alert Message',
    'are_you_confirmed_to_execute_this_operation' => 'Are you confirmed to execute this operation ?',
    'yes' => 'yes',
    'business_information' => 'Business Information',
    'business_owner_name' => 'Legal Name/ Business Owner Name',
    'country_region' => 'Country/ Region',
    'person_in_charge_name' => 'Person in Charge Name',
    'business_registration_number' => 'Business Registration Number',
    'seller_tin' => 'Seller TIN',
    'upload_business_document' => 'Upload Business Document',
    'display_name' => 'Display Name',
    'shop_name' => 'Shop Name',
    'holiday_mode' => 'HoliDay Mode',
    'holiday_start' => 'Holiday Start',
    'holiday_end' => 'Holiday End',
    'upload_cheque_copy' => 'Upload Cheque Copy',
    'same_as_warehouse_address' => 'Same as Warehouse Address',
    'order_status' => 'Order Status',
    'delivery_status' => 'Delivery Status',
    'no_of_product' => 'No. of product',
    'txn_id' => 'TXN ID',
    'commission_type' => 'Commission Type',
    'approval' => 'Approval',
    'check_category_commissions' => 'Check Category Commissions',
    'category_list_with_commission' => 'Category list with Commission',
    'my_staff' => 'My Staff',
    'add_new_staff' => 'Add New Staff',
    'create_a_staff' => 'Create A Staff',
    'update_staff_info' => 'Update staff info',
    'joined_date' => 'Joined Date',
    'select_from_list' => 'Select from list',
    'add_member_is_disabled_according_to_your_package_right_now' => 'Add Member is disabled according to your package right now',
    'seller_list' => 'Seller List',
    'commision_setup' => 'Commision Setup',
    'subscription_payment' => 'Subscription Payment',
    'manage_seller' => 'Manage Seller',
    'subscription_info' => 'Subscription info',
    'subscription_title' => 'Subscription Title',
    'next_payment_before' => 'Next payment before',
    'subscription_payments' => 'Subscription payments',
    'create_supplier' => 'Create supplier',
    'business_name' => 'Business name',
    'tax_number' => 'Tax number',
    'edit_supplier' => 'Edit Supplier',
    'supplier_id' => 'Supplier id',
    'supplier' => 'Supplier',
    'supplier_list' => 'Supplier list',
    'pay_condition' => 'Pay condition',
    'finance_information' => 'Finance Information',
    'opening_balance' => 'Opening Balance',
    'pay_term' => 'PAY Term',
    'pay_term_condition' => 'Pay Term Condition',
    'alternate_contact_no' => 'Alternate Contact No',
    'postcode' => 'Postcode',
    'supplier_profile' => 'Supplier Profile',
    'office_xtract' => 'OfficeXtract',
    'please_update_business_bank_information_from_profile_first' => 'Please Update Business & Bank Information From Profile First.',
    'seller_profile' => 'Seller Profile',
    'product_allready_added' => 'Product Allready Added.',
    'about_seller' => 'About Seller',
    'commission_calculate_for_multi_category' => 'Commission Calculate For Multi Category',
    'minimum_rate' => 'Minimum Rate',
    'maximum_rate' => 'Maximum Rate',
    'average_rate' => "Average Rate",
    'multi_category' => 'Multi Category',
    'expire_date' => 'Expire date',
    'already_expired' => 'Already Expired',
    'last_payment_date' => 'Last Payment Date',
    'advance_renew_subscription' => 'Advance renew subscription',
    'after_change_and_save_previous_lisence_will_expried' => 'After change and save previous lisence will expried.',
    'Request/Inactive seller list' => 'Request/Inactive seller list',
    'Seller setting' => 'Seller setting',
    'Seller Order Manage' => 'Order Manage',
    'order_refund_status' => 'Request Status',
    'is_refunded' => 'Is Refunded',
    'OrderRefund_action' =>'Action',
    'regular_seller' =>'Regular Seller',
    'total_commision' => 'Total Commision',
    'request_inactive_seller_list' => 'Request/Inactive Seller List',
    'seller_setting' => 'Seller Setting',
    'new_password' => "New Password",
    "update_business_info"=> "Update Business Info",
    "change_password"=> "Change Password",
];
